@@ -342,7 +342,7 @@ class BundlingOptions:
                 asset_hash_type: typing.Optional[aws_cdk.core.AssetHashType] = None,
                 build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
                 cgo_enabled: typing.Optional[builtins.bool] = None,
-                command_hooks: typing.Optional["ICommandHooks"] = None,
+                command_hooks: typing.Optional[ICommandHooks] = None,
                 docker_image: typing.Optional[aws_cdk.core.DockerImage] = None,
                 environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
                 forced_docker_bundling: typing.Optional[builtins.bool] = None,
